/*
 * Copyright(c)  2002  Rijkswaterstaat
 *                     Dienst Verkeerskunde
 *                     WSRA
 * File:               CRAPTAB.C
 *
 * Nummer kruispunt:        1
 * Regelprogramma vri:      voorbeeldregeling aftrekken tijden
 *
 * datum:                   27 januari 1994
 * gewijzigd:               10 maart 2003 EPARM voor af te trekken tijd ipv TIJD
 * gewijzigd:               18 juni 2004 aanpassing aan RWS C-versie 7.14
 * versie:                  4.1
 */

#include "crtypes.h"
#include "crapcod.h"
#include "craptab.h"
#include "ccie_int.h"
#include "crapdef.h"

/*     BLOKKEN schema                                           */
struct BLOKKEN  BLOKKEN_tabel[] = {
/*     blok:    sg:     toewijzing:                             */
/*     BKl,     SGn,    PRIM + WSGR + ALT,                      */
       BK1,     SG01,                 ALT,
       BK1,     SG02,   PRIM,

       BK2,     SG05,   PRIM,
       STOP};

/*     CONFLICT- en (garantie)ontruimingstijden matrix          */
struct CONFLICT  CONFLICT_tabel[] = {
/*                                    instellingen              */
/*                                    van de tijden:            */
/*     sg:       conflicterende sg:   GO_TIJD:  O_TIJD:         */
/*     SGn,      SGj,                 x.y,      x.y,            */
       SG01,     SG05,                2.0,      2.0,

       SG02,     SG05,                2.0,      2.0,

       SG05,     SG01,                2.0,      2.0,
       SG05,     SG02,                2.0,      2.0,
       STOP};

/*     SignaalGroep_TIJDEN tabel                                */
struct SG_TIJDEN  SG_TIJDEN_tabel[] = {
/*            instellingen van de tijden:                       */
/*     sg:    GG_TIJD:  VG_TIJD:  GGL_TIJD:  GL_TIJD:  GR_TIJD: */
/*     SGn,    x.y,      x.y,      x.y,       x.y,      x.y,    */
       SG01,   4.0,      4.0,      3.0,       3.0,      2.0,
       SG02,   4.0,      4.0,      3.0,       3.0,      2.0,
       SG05,   4.0,      4.0,      3.0,       3.0,      2.0,
       STOP};

/*     MG_TIJDEN tabel                                          */
struct MG_TIJDEN  MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD:  MG_TIJD1:  MG_TIJD2:  MG_TIJD3:         */
/*                      dal        ochtend    avond             */
/*     SGn,    x.y,      x.y,       x.y,       x.y,             */
       SG01,    NG,     10.0,      10.0,      10.0,     
       SG02,    NG,     20.0,      30.0,      40.0,     
       SG05,    NG,     20.0,      30.0,      40.0,     
       STOP};

/*     Extra MG_TIJDEN tabel                                    */
struct E_MG_TIJDEN  E_MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD4:  MG_TIJD5:     MG_TIJD6:                */
/*            koopavond  t.b.v testen                           */
/*     SGn;    x.y,       x.y,         x.y,                     */
       SG01,  10.0,      10.0,        70.0,     
       SG02,  50.0,      60.0,        70.0,     
       SG05,  50.0,      60.0,        70.0,     
       STOP};

/*     SignaalGroep-DETECTIE tabel                              */
struct SG_DETECTIE           SG_DETECTIE_tabel[] = {
/*     D():     type:        sg:     toewijzing:                */
/*     SGn_i,   DP (of DK),  SGn,    AVR + BS_H5p + H1e + H2e,  */
       SG01_1,  DP,          SG01,   AVR + BS_H5p,

       SG02_1,  DP,          SG02,   AVR + BS_H5p,

       SG05_1,  DP,          SG05,   AVR + BS_H5p,

       SG99_1,  DP,          SG05,   GEEN,
       STOP};

/*     tabel voor SG'en die gebruik maken van PPAH en VNMH      */
struct SG_PPAH  SG_PPAH_tabel[] = {
/*     PPAH() (en VNMH()):   TIJD():                            */
/*     SGn,                  T_PPAH_n,                          */
       SG02,                 T_PPA_02,
       STOP};

/*     TIJDENtabel                                              */
struct TIJDEN                TIJDEN_tabel[] = {
/*     TIJD():               instelling:                        */
/*     NAAM,                  x.y,                              */
       T_PPA_02,              0.0, /* tijd tbv bepalen gebied alt. realisatie */
                                   /* wordt berekend in CRAPCOD.C             */
       STOP};

/*     KLOKKENtabel                                             */
struct KLOKKEN KLOKKEN_tabel[] = {
/*     KL():                    1e tijdstip:  2e tijdstip:      */
/*     NAAM,                     x.yz,         x.yz,            */
       K_OCHTEND,                7.00,         9.00,
       K_AVOND,                 16.00,        20.00,
       K_KOOPAVOND_E1,          19.00,        22.00,
       K_EXTRA_2,               10.00,        19.00,
       STOP};

/*     EGGPARMStabel                                            */
struct EGGPARMS           EGGPARMS_tabel[] = {
/*     EGGPARM():         instelling:                           */
/*     NAAM,               x,                                   */
       EG_KOOPAVONDDAG_E1, 4, /* 0: zondag    1: maandag           */
                              /* 2: dinsdag   3: woensdag          */
                              /* 4: donderdag 5: vrijdag           */
                              /* 6: zaterdag  7: werkdagen (ma-vr) */
                              /* 8: weekend   9: weekdagen (ma-zo) */
                              /* 99: niet gebruikt                 */
       EG_DAG_EXTRA_2,     6, /* 0: zondag    1: maandag           */
                              /* 2: dinsdag   3: woensdag          */
                              /* 4: donderdag 5: vrijdag           */
                              /* 6: zaterdag  7: werkdagen (ma-vr) */
                              /* 8: weekend   9: weekdagen (ma-zo) */
                              /* 99: niet gebruikt                 */
       STOP};

/*     EPARMStabel                                              */
struct EPARMS             EPARMS_tabel[] = {
/*     EPARM():           instelling:                           */
/*     NAAM,               x.y,                                 */
       EP_PPA_02,         10.0, /* aftrektijd tbv bepalen gebied alt. realisatie */
       STOP};

/*     SG gebonden optie: VAA_OP(SGn)                           */
struct SG_OPTIE           VAA_OP_tabel[] = {
/*     optie voor sg:     inhoud van de optie:                  */
/*     SGn,               WAAR (of functie),                    */
       SG02,              WAAR,
       SG05,              WAAR,
       STOP};

/*     SG gebonden optie: PPV_OP(SGn)                           */
struct SG_OPTIE           PPV_OP_tabel[] = {
/*     optie voor sg:     inhoud van de optie:                  */
/*     SGn,               WAAR (of functie),                    */
       SG02,              WAAR,
       SG05,              WAAR,
       STOP};

/*     SG en BK gebonden optie:    PPA_OP(SGn, BKl)             */

Bool PPA_funct_01_1 (void) { return PPAH(SG02); }

struct SG_BK_OPTIE                 PPA_OP_tabel[] = {
/*     optie voor sg:  voor blok:  inhoud van de optie:         */
/*     SGn,            BKl,        functie,                     */
       SG01,           BK1,        PPA_funct_01_1,
       STOP};

/*     SG en BK gebonden optie:    VNM_OP(SGn, BKl)             */

Bool VNM_funct_01_1 (void) { return VNMH(SG02); }

struct SG_BK_OPTIE                 VNM_OP_tabel[] = {
/*     optie voor sg:  voor blok:  inhoud van de optie:         */
/*     SGn,            BKl,        functie,                     */
       SG01,           BK1,        VNM_funct_01_1,
       STOP};

/*     REGELINGtabel                                            */
struct REGELING           REGELING_tabel[] = {
/*     Nummer                                                   */
       1,
       STOP};

struct WB WB_tabel[] = {STOP};
struct FICT_CONFLICT FICT_CONFLICT_tabel[] = {STOP};
struct SG_BS_H5t SG_BS_H5t_tabel[] = {STOP};
struct SG_BS_H5ac SG_BS_H5ac_tabel[] = {STOP};
struct SG_BS_H66 SG_BS_H66_tabel[] = {STOP};
struct H_TIJDEN  H_TIJDEN_tabel[] = {STOP};
struct E_H_TIJDEN E_H_TIJDEN_tabel[] = {STOP};
struct SG_RGA SG_RGA_tabel[] = {STOP};
struct FIETS_VOETG_R FIETS_VOETG_R_tabel[] = {STOP};
struct SG_MAH3 SG_MAH3_tabel[] = {STOP};
struct SG_WSRH SG_WSRH_tabel[] = {STOP};
struct SCHAKELAAR SCHAKELAAR_tabel[] = {STOP};
struct BK_OPTIE BO_OP_tabel[] = {STOP};
struct SG_OPTIE MA_OP_tabel[] = {STOP};
struct SG_BK_OPTIE PPP_OP_tabel[] = {STOP};
struct SG_OPTIE MVG_OP_tabel[] = {STOP};
struct SG_OPTIE TR_OP_tabel[] = {STOP};
struct SG_OPTIE PPB_OP_tabel[] = {STOP};
struct SG_OPTIE AFK_OP_tabel[] = {STOP};
struct SG_OPTIE BL_OP_tabel[] = {STOP};
struct SG_OPTIE RVG_OP_tabel[] = {STOP};
struct SG_OPTIE VAG_OP_tabel[] = {STOP};
struct SG_OPTIE VMG_OP_tabel[] = {STOP};
struct KOPPEL KOPPEL_tabel[] = {STOP};
